==> jc-1.4.0.tar.gz: soot/jimple/internal/JCastExpr.h <==
// public class soot.jimple.internal.JCastExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f314930900c2c411 soot_jimple_internal_AbstractCastExpr
// @dep_class 608ec91335eb7170 soot_jimple_internal_JCastExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractCastExpr

#include "soot/jimple/internal/AbstractCastExpr.h"

#ifndef _JC_soot_jimple_internal_JCastExpr_H_
#define _JC_soot_jimple_internal_JCastExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JCastExpr$sub_refs	_jc_soot_jimple_internal_JCastExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JCastExpr$sub_nonrefs	_jc_soot_jimple_internal_JCastExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JCastExpr$refs	_jc_soot_jimple_internal_JCastExpr$refs;
typedef struct _jc_soot_jimple_internal_JCastExpr$nonrefs	_jc_soot_jimple_internal_JCastExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JCastExpr$object	_jc_soot_jimple_internal_JCastExpr$object;

typedef const struct _jc_soot_jimple_internal_JCastExpr$vmethods	_jc_soot_jimple_internal_JCastExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JCastExpr$vtable	_jc_soot_jimple_internal_JCastExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JCastExpr$vtype	_jc_soot_jimple_internal_JCastExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JCastExpr$method$_init$743c179cbcd16e16(_jc_env *, struct _jc_soot_jimple_internal_JCastExpr$object *, struct _jc_object *, struct _jc_soot_Type$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JCastExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JCastExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JCastExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JCastExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JCastExpr$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JCastExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractCastExpr$vmethods	soot_jimple_internal_AbstractCastExpr;
	_jc_soot_jimple_internal_JCastExpr$vmethods	soot_jimple_internal_JCastExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JCastExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JCastExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JCastExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JCastExpr$refs {
    _jc_soot_jimple_internal_JCastExpr$sub_refs	soot_jimple_internal_JCastExpr;
    _jc_soot_jimple_internal_AbstractCastExpr$sub_refs	soot_jimple_internal_AbstractCastExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JCastExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JCastExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractCastExpr$sub_nonrefs	soot_jimple_internal_AbstractCastExpr;
    _jc_soot_jimple_internal_JCastExpr$sub_nonrefs	soot_jimple_internal_JCastExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JCastExpr$object {
	_jc_soot_jimple_internal_JCastExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JCastExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JCastExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JCastExpr$vtype _jc_soot_jimple_internal_JCastExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JCastExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JCastExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JCastExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JCastExpr.h <==
// public class soot.jimple.internal.JCastExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f314930900c2c411 soot_jimple_internal_AbstractCastExpr
// @dep_class 608ec91335eb7170 soot_jimple_internal_JCastExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractCastExpr

#include "soot/jimple/internal/AbstractCastExpr.h"

#ifndef _JC_soot_jimple_internal_JCastExpr_H_
#define _JC_soot_jimple_internal_JCastExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JCastExpr$sub_refs	_jc_soot_jimple_internal_JCastExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JCastExpr$sub_nonrefs	_jc_soot_jimple_internal_JCastExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JCastExpr$refs	_jc_soot_jimple_internal_JCastExpr$refs;
typedef struct _jc_soot_jimple_internal_JCastExpr$nonrefs	_jc_soot_jimple_internal_JCastExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JCastExpr$object	_jc_soot_jimple_internal_JCastExpr$object;

typedef const struct _jc_soot_jimple_internal_JCastExpr$vmethods	_jc_soot_jimple_internal_JCastExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JCastExpr$vtable	_jc_soot_jimple_internal_JCastExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JCastExpr$vtype	_jc_soot_jimple_internal_JCastExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JCastExpr$method$_init$743c179cbcd16e16(_jc_env *, struct _jc_soot_jimple_internal_JCastExpr$object *, struct _jc_object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JCastExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JCastExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JCastExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JCastExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JCastExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JCastExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractCastExpr$vmethods	soot_jimple_internal_AbstractCastExpr;
	_jc_soot_jimple_internal_JCastExpr$vmethods	soot_jimple_internal_JCastExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JCastExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JCastExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JCastExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JCastExpr$refs {
    _jc_soot_jimple_internal_JCastExpr$sub_refs	soot_jimple_internal_JCastExpr;
    _jc_soot_jimple_internal_AbstractCastExpr$sub_refs	soot_jimple_internal_AbstractCastExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JCastExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JCastExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractCastExpr$sub_nonrefs	soot_jimple_internal_AbstractCastExpr;
    _jc_soot_jimple_internal_JCastExpr$sub_nonrefs	soot_jimple_internal_JCastExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JCastExpr$object {
	_jc_soot_jimple_internal_JCastExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JCastExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JCastExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JCastExpr$vtype _jc_soot_jimple_internal_JCastExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JCastExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JCastExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JCastExpr_H_ */
